pub trait NetworkStream: Read + Write { }Expand description
Used by Client to represent types that are Read and Write.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait NetworkStream: Read + Write { }Used by Client to represent types that are Read and Write.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".